==> nxnode-3.0.0-83.x86_64.tar.gz: NX/scripts/restricted/nxuseradd.sh <==
#!/bin/sh
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.r.l.                     #
#                                                                          #
#  All rigths reserved.                                                    #
#                                                                          #
############################################################################
NODE_ROOT='/usr/NX'
COMMAND_ECHO="/bin/echo"

if [ $# -gt 7 -a $# -lt 3 ] ; then
          $COMMAND_ECHO "NX> 599 Error: Wrong parameters count." && exit 1
fi 

if [ "x$1" != "xnx" -a "x$1" != "xroot" ];
  then
    $COMMAND_ECHO "NX> 599 Error: nxuseradd.sh: only 'nx' user can add a system user by this script" 1>&2
    exit 1
fi

COMMAND_USERADD="/usr/sbin/useradd"

COMMAND_USERMOD="/usr/sbin/usermod"

COMMAND_SU="/bin/su"

COMMAND_NXNODE="$NODE_ROOT/bin/nxnode"

SET_HOME=""

ADD_UID=""

ADD_GID=""

ADD_HOME="-m"

if [ ! -x $COMMAND_USERADD ];
then
  $COMMAND_ECHO "NX> 599 Error: command $COMMAND_USERADD doesn't exist"
  exit 1
fi

if [ ! -x $COMMAND_USERMOD ];
then
  $COMMAND_ECHO "NX> 599 Error: command $COMMAND_USERMOD doesn't exist"
  exit 1
fi

if [ ! -x $COMMAND_SU ];
then
  $COMMAND_ECHO "NX> 599 Error: command $COMMAND_SU doesn't exist"
  exit 1
fi

if [ ! -x $COMMAND_NXNODE ];
then
  $COMMAND_ECHO "NX> 599 Error: command $COMMAND_NXNODE doesn't exist"
  exit 1
fi

if [ ! -x $COMMAND_ECHO ];
then
  $COMMAND_ECHO "NX> 599 Error: command $COMMAND_NXNODE doesn't exist"
  exit 1
fi

if [ "x$7" != "x" ];
then
  ADD_HOME=""
fi

if [ "x$4" != "x" ];
then
  SET_HOME="-d $4/$3"
fi

if [ "x$5" != "x" ];
then
  ADD_UID="-u $5 -o"
fi

if [ "x$6" != "x" ];
then
ADD_GID="-g $6"
fi 
  
$COMMAND_USERADD $SET_HOME $ADD_GID $ADD_UID $ADD_HOME $3 && $COMMAND_USERMOD -U $3 && $COMMAND_ECHO "setkey" | $COMMAND_SU $3 -c $COMMAND_NXNODE
exit $?

==> nxnode-3.1.0-6.x86_64.tar.gz: NX/scripts/restricted/nxuseradd.sh <==
#!/bin/sh
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.r.l.                     #
#                                                                          #
#  All rigths reserved.                                                    #
#                                                                          #
############################################################################
NODE_ROOT='/usr/NX'
COMMAND_ECHO="/bin/echo"
COMMAND_NSCD="/usr/sbin/nscd"

if [ $# -gt 7 -a $# -lt 3 ] ; then
          $COMMAND_ECHO "NX> 599 Error: Wrong parameters count." && exit 1
fi 

if [ "x$1" != "xnx" -a "x$1" != "xroot" ];
  then
    $COMMAND_ECHO "NX> 599 Error: nxuseradd.sh: only 'nx' user can add a system user by this script" 1>&2
    exit 1
fi

COMMAND_USERADD="/usr/sbin/useradd"

COMMAND_USERMOD="/usr/sbin/usermod"

COMMAND_SU="/bin/su"

COMMAND_NXNODE="$NODE_ROOT/bin/nxnode"

SET_HOME=""

ADD_UID=""

ADD_GID=""

ADD_HOME="-m"

if [ ! -x $COMMAND_USERADD ];
then
  $COMMAND_ECHO "NX> 599 Error: command $COMMAND_USERADD doesn't exist"
  exit 1
fi

if [ ! -x $COMMAND_USERMOD ];
then
  $COMMAND_ECHO "NX> 599 Error: command $COMMAND_USERMOD doesn't exist"
  exit 1
fi

if [ ! -x $COMMAND_SU ];
then
  $COMMAND_ECHO "NX> 599 Error: command $COMMAND_SU doesn't exist"
  exit 1
fi

if [ ! -x $COMMAND_NXNODE ];
then
  $COMMAND_ECHO "NX> 599 Error: command $COMMAND_NXNODE doesn't exist"
  exit 1
fi

if [ ! -x $COMMAND_ECHO ];
then
  $COMMAND_ECHO "NX> 599 Error: command $COMMAND_NXNODE doesn't exist"
  exit 1
fi

if [ "x$7" != "x" ];
then
  ADD_HOME=""
fi

if [ "x$4" != "x" ];
then
  SET_HOME="-d $4/$3"
fi

if [ "x$5" != "x" ];
then
  ADD_UID="-u $5 -o"
fi

if [ "x$6" != "x" ];
then
ADD_GID="-g $6"
fi 
  
$COMMAND_USERADD $SET_HOME $ADD_GID $ADD_UID $ADD_HOME $3
if [ $? != 0 ];
then
  exit $?
fi
$COMMAND_USERMOD -U $3

if [ -f /etc/nscd.conf ]
then
  $COMMAND_NSCD --invalidate=passwd
fi
 
$COMMAND_ECHO "setkey" | $COMMAND_SU $3 -c $COMMAND_NXNODE
exit $?
